#ifndef USER_H_
#define USER_H_


#include "DSP28x_Project.h"								// Headers for C28346
#include "extern_user.h"								// Corresponding pre-compiled header


/**
 * Pre-computed general constants
 */
#define PI 					(3.141592654)
#define TWOPI 				(2*PI)
#define TWOPI_OVER_THREE 	(TWOPI/3.0)
#define OMEGA 				(TWOPI*50.0)


/**
 * Time-related definitions
 */
#define SWITCHING_FREQUENCY	(20e3)						// Apparent switching frequency
#define SWITCHING_PERIOD	(1/SWITCHING_FREQUENCY)		// Switching period
#define OUTPUT_FREQUENCY	(50)						// Output frequency
#define SAMPLING_PERIOD		(1/SWITCHING_FREQUENCY)		// Sampling and control period (dsp)
#define SAMPLING_PERIOD_US	(1/SWITCHING_FREQUENCY*1e6)	// Same thing in microseconds...
#define FPGA_CLK_PERIOD		(33.33e-9)					// 30Mhz -> 33.3ns
#define DEADTIME			(300e-9)					// Dead time


/**
 * Aliases improving the readability of some parts of the code
 */
#define FREQGEN0			0
#define FREQGEN1			1
#define FREQGEN2			2
#define FREQGEN3			3


/**
 * First user-level interrupt service routine.
 * Remember that it has the highest level of priority when mapped to Ext1, intermediate when
 * mapped to Ext2 and lowest when mapped to the CPU Timer.
 * @param	void	no parameters
 * @return 			SAFE or UNSAFE depending on whether the user wants to trigger the blocking of the application or not
 */
USER_SAFE UserInterrupt1(void);


/**
 * First user-level interrupt service routine.
 * Remember that it has the highest level of priority when mapped to Ext1, intermediate when
 * mapped to Ext2 and lowest when mapped to the CPU Timer.
 * @param	void	no parameters
 * @return 			SAFE or UNSAFE depending on whether the user wants to trigger the blocking of the application or not
 */
USER_SAFE UserInterrupt2(void);


#endif /* USER_H_ */
